Learn R Programming

shelter (version 0.2.1)

keyring_list: Provides a `data.frame` of information on available keyrings.

Description

Looks in a local directory where keyrings are stored for the current user and returns information about keyrings found. Keyrings are stored in `rappdirs::user_config_dir("r-shelter")` and end in `.keyring.RDS`

Usage

keyring_list()

Arguments

Value

data.frame of (keyring, secrets, locked)

Examples

Run this code
keyring_list()

Run the code above in your browser using DataLab