unsafe_export: Export keyring to plain text format as a string.
Description
This functions exports a keyring to a file as a convenience function
for production deployments.
Usage
unsafe_export(keyring, format, yaml_tag = "shelter", warn = TRUE)
Value
A character(1) string of the desired export.
Arguments
keyring
character(1); Name of keyring.
format
character(1); One of 'yaml' or 'ENV'.
yaml_tag
character(1); Tag to use in 'yaml'. Defaults to 'shelter'
warn
boolean(1); Should the user be warned of the dangers. Defaults to TRUE.
Details
WARNING: It is not recommended to use this function
unless you are deploying to a hardened secured production environment. To
restate, if you are developing on a personal laptop a report or code
this function should NOT be used.